**Project Portfolio: https://github.com/calebyhan/CalebHan** 

# chemistry-ch

Python library for chemistry equations and formulas.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install chemistry-ch.

```bash
pip install foobar
```

## Usage

```python
import chemistry

# returns atomic mass of Hydrogen
chemistry.mass(1)
chemistry.mass("H")

# returns a metric conversion from 1 cm to km
chemistry.Conversions.metric(1, "c", "k")

# returns molarity of a solution with 1 mol in 2 L
chemistry.Formulas(moles=1, volume=1)
```

## Documentation


## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)